#ifndef BASICUNITTESTS_H
#define BASICUNITTESTS_H

#include "paper.h"
#include "graphicsstroke.h"
#include "storage.h"

class BasicUnitTests : public QObject
{
    Q_OBJECT

public:
    BasicUnitTests(QObject *parent = 0);
    ~BasicUnitTests();

private slots:
    /// Test the save & load of GraphicsStroke class
    void stroke_save_load();

};

class StorageUnitTests : public QObject {
    Q_OBJECT

private slots:
    void initTestCase();

};

#endif // BASICUNITTESTS_H
